@@ -1,7 +1,8 @@
 /* WavSplit by Tobias Weihmann  */
 /* Licensed under GPL           */
 /* Contact: tobias@fomalhaut.de */
-/* Updated to version 1.0.0 by Alan Fitch, apfitch@ieee.org */ 
+/* Updated to version 1.0.0 by Alan Fitch, apfitch@ieee.org */
+/* Version 1.1.0 - fixed bug in TokenOK, fps can be set to 12 */
 #include "wavsplit.h"
 
 int main (int argc, char *argv[])
@@ -44,30 +45,32 @@ int main (int argc, char *argv[])
     case OPF_QUIET:
     case 0:
       verbose = 0;
-      Report("Quiet option selected","INFO",verbose);
+      Report ("Quiet option selected", "INFO", verbose);
       break;
     case OPF_HELP:
       usage ();
       return 1;
     case OPF_HOURS:
       UseHours = 1;
-      Report("Hours:mins:sec format selected","INFO",verbose);
+      Report ("Hours:mins:sec format selected", "INFO", verbose);
       break;
     case OPF_SECONDS:
       UseSeconds = 1;
-      Report ("Seconds only option selected","INFO",verbose);
+      Report ("Seconds only option selected", "INFO", verbose);
       break;
     case OPF_FRAMES:
       UseFrames = 1;
-      Report("Frames options selected","INFO",verbose);
+      Report ("Frames options selected", "INFO", verbose);
       if (optarg) {
         fps = atoi (optarg);
         if (!checkfps (fps)) {
-          Report("Frames argument must be 24, 25, or 30","ERROR",verbose);
+          Report ("Frames argument must be 12, 24, 25, or 30", "ERROR",
+                  verbose);
         }
       }
       else {
-        Report("Missing argument to frames option 24, 25, or 30 fps","ERROR",verbose);
+        Report ("Missing argument to frames option 12, 24, 25, or 30 fps",
+                "ERROR", verbose);
       }
       break;
     default:
@@ -81,7 +84,9 @@ int main (int argc, char *argv[])
   }
 
   if ((UseHours == 1) && (UseSeconds == 1)) {
-    Report("You selected time in just seconds, and in hours - only one is allowed","ERROR", verbose);
+    Report
+      ("You selected time in just seconds, and in hours - only one is allowed",
+       "ERROR", verbose);
   }
 
   strcpy (ifile, argv[optind]);
@@ -101,7 +106,7 @@ int main (int argc, char *argv[])
       if (UseFrames) {
         strtokPtr = strtok (argv[optind + 1 + i], ":");
         splitpos[i].seki = atoi (strtokPtr);
-        if (!TokenOK ("Frame Counter", strtokPtr))
+        if (!TokenOK ("Frame Counter", &strtokPtr))
           return 1;
         splitpos[i].frames = atof (strtokPtr);
       }
@@ -110,30 +115,30 @@ int main (int argc, char *argv[])
       }                         /* end if useframes */
     }
     else {                      /* not using seconds */
-
+      strtokPtr = strtok (argv[optind + 1 + i], ":");
       if (UseHours) {
-        splitpos[i].hr = atoi (strtok (argv[optind + 1 + i], ":"));
-        if (!TokenOK ("Minutes", strtokPtr))
+        splitpos[i].hr = atoi (strtokPtr);
+        if (!TokenOK ("Minutes", &strtokPtr))
           return 1;
         splitpos[i].min = atoi (strtokPtr);
       }
       else {                    /* not usehours */
-        splitpos[i].min = atoi (strtok (argv[optind + 1 + i], ":"));
+        splitpos[i].min = atoi (strtokPtr);
       }                         /* end if usehours */
 
       if (UseFrames) {
         /* expect integer seconds followed by floating point frames */
-        if (!TokenOK ("Seconds", strtokPtr))
+        if (!TokenOK ("Seconds", &strtokPtr))
           return 1;
         splitpos[i].seki = atoi (strtokPtr);
 
-        if (!TokenOK ("Frame Counter", strtokPtr))
+        if (!TokenOK ("Frame Counter", &strtokPtr))
           return 1;
         splitpos[i].frames = atof (strtokPtr);
       }                         /* not useframe */
       else {
         /* expect floating point seconds and no frames */
-        if (!TokenOK ("Seconds", strtokPtr))
+        if (!TokenOK ("Seconds", &strtokPtr))
           return 1;
 
         splitpos[i].sek = atof (strtokPtr);
@@ -142,19 +147,22 @@ int main (int argc, char *argv[])
 
     /* Check that values are valid */
     if (UseFrames) {
-      if ((splitpos[i].frames < 0.0) || (splitpos[i].frames >= (float) fps)) {
-        Report("When using frames, minutes must be >= 0.0  and <= Frames Per Second","ERROR",verbose);
+      if (!((splitpos[i].frames > 0.0) && (splitpos[i].frames < (float) fps))) {
+        Report
+          ("When using frames, value must be >= 0.0  and < Frames Per Second",
+           "ERROR", verbose);
       }
     }
     if (!UseSeconds) {
-      if (((splitpos[i].sek < 0.0) || (splitpos[i].sek >= 60.0))) {
-        Report("Seconds must be >= 0.0  and <= 60.0","ERROR",verbose);
+      if (!((splitpos[i].sek >= 0.0) && (splitpos[i].sek < 60.0))) {
+        Report ("Seconds must be >= 0.0  and < 60.0", "ERROR", verbose);
       }
-      if (((splitpos[i].seki < 0) || (splitpos[i].seki >= 60))) {
-        Report("Seconds must be >= 0  and <= 60","ERROR",verbose);
-     }
-      if ((splitpos[i].min < 0) || (splitpos[i].min >= 60)) {
-        Report("When using Hours, minutes must be >= 0  and <= 60","ERROR",verbose);
+      if (!((splitpos[i].seki >= 0) && (splitpos[i].seki < 60))) {
+        Report ("Seconds must be >= 0  and < 60", "ERROR", verbose);
+      }
+      if (UseHours && !((splitpos[i].min >= 0) && (splitpos[i].min < 60))) {
+        Report ("When using Hours, minutes must be >= 0  and < 60", "ERROR",
+                verbose);
       }
     }                           /* end if !useseconds */
 
@@ -189,15 +197,17 @@ void usage ()
 {
   printf ("Usage: wavsplit [options] wavfile split split split...\n\n");
   printf ("Options:\n");
-  printf ("\t-%c\t--%s\t\tQuiet mode (no messages)\n", OPF_QUIET,OPF_QUIET_LONG);
+  printf ("\t-%c\t--%s\t\tQuiet mode (no messages)\n", OPF_QUIET,
+          OPF_QUIET_LONG);
   printf ("\t-%c\t--%s\t\tUse Hours\n", OPF_HOURS, OPF_HOURS_LONG);
   printf ("\t\t\t\twavsplit [options] wavfile hr:min:sec [hr:min:sec]...\n");
   printf ("\t-%c\t--%s FPS\tuse Frames\n", OPF_FRAMES, OPF_FRAMES_LONG);
-  printf ("\t\t\t\tFPS (frames per second) must be either 24, 25, or 30\n");
+  printf
+    ("\t\t\t\tFPS (frames per second) must be either 12, 24, 25, or 30\n");
   printf ("\t\t\t\twavsplit [options] wavfile min:sec:fr [min:sec:fr]...\n");
-  printf ("\t-%c\t--%s\tUse Seconds\n", OPF_SECONDS,OPF_SECONDS_LONG);
+  printf ("\t-%c\t--%s\tUse Seconds\n", OPF_SECONDS, OPF_SECONDS_LONG);
   printf ("\t\t\t\twavsplit [options] wavfile sec [sec]...\n");
-  printf ("\t-%c\t--%s\t\tThis info\n", OPF_HELP,OPF_HELP_LONG);
+  printf ("\t-%c\t--%s\t\tThis info\n", OPF_HELP, OPF_HELP_LONG);
   printf ("\nYou can combine both Hours and frames options\n");
   printf ("\nExamples:\n");
   printf ("\t\t\twavsplit --frames 30 file.wav 32:21:15 45:10:0\n");
@@ -205,21 +215,25 @@ void usage ()
   printf ("\t\t\twavsplit --seconds file.wav 300.1 500.2\n\n");
 }
 
-void Report(const char * Message, const char * Severity, int Verbose) 
+void Report (const char *Message, const char *Severity, int Verbose)
 {
-  int IsError = !strcmp(Severity,"ERROR");
-  int IsInfo  = !strcmp(Severity,"INFO");
+  int IsError = !strcmp (Severity, "ERROR");
+  int IsInfo = !strcmp (Severity, "INFO");
   assert (IsError || IsInfo);
-  if ((IsInfo) && (Verbose))  printf("%s: %s\n",Severity,Message);
-  if (IsError) fprintf(stderr,"%s: %s\n",Severity,Message);
-  if (IsError) exit(1);
+  if ((IsInfo) && (Verbose))
+    printf ("%s: %s\n", Severity, Message);
+  if (IsError)
+    fprintf (stderr, "%s: %s\n", Severity, Message);
+  if (IsError)
+    exit (1);
 }
 
-int TokenOK (const char *Message, char *strPtr)
+int TokenOK (const char *Message, char **strPtr)
 {
-  strPtr = strtok (NULL, ":");
-  if (strPtr == NULL) {
-    fprintf (stderr,"ERROR: wavsplit: Argument error, expecting %s\n", Message);
+  *strPtr = strtok (NULL, ":");
+  if (*strPtr == NULL) {
+    fprintf (stderr, "ERROR: wavsplit: Argument error, expecting %s\n",
+             Message);
     exit (1);
   }
   return 1;
@@ -227,12 +241,11 @@ int TokenOK (const char *Message, char *strPtr)
 
 int checkfps (unsigned int fps)
 {
-  return (fps == 24) || (fps == 25) || (fps == 30);
+  return (fps == 12) || (fps == 24) || (fps == 25) || (fps == 30);
 }
 
 int split (unsigned int UseHours, unsigned int UseFrames,
-           unsigned int fps,
-           int splits, timepos * split)
+           unsigned int fps, int splits, timepos * split)
 {
   char *buf, *bp_out;
   long to_write, to_read, n_read, pos;
@@ -288,9 +301,7 @@ int split (unsigned int UseHours, unsigned int UseFrames,
         to_read -= to_write;
 
         if (++fnr < splits) {
-          to_write =
-            calcsplit (UseHours, UseFrames, fps, fnr,
-                       split) - pos;
+          to_write = calcsplit (UseHours, UseFrames, fps, fnr, split) - pos;
         }
         else {
           to_write = databytes - pos;
@@ -301,8 +312,9 @@ int split (unsigned int UseHours, unsigned int UseFrames,
           }
           else {
             if (verbose)
-              printf ("[%02d]\tuntil the end\t\t%09ld\t100.00%%\n",
-                      fnr + 1, databytes);
+              printf
+                ("[%02d]\tuntil the end                %12ld   100.00%%\n",
+                 fnr + 1, databytes);
           }
         }
         pos += to_write;
@@ -401,6 +413,7 @@ int readheader ()
     printf ("Samplerate: %ldHz\n", waveformat.dwSamplesPerSec);
     printf ("Samplebits: %d\n", waveformat.wBitsPerSample);
     printf ("Databytes: %ld\n\n", databytes);
+    printf ("Split         Hours  Mins   Seconds         Bytes         %%\n");
     //printf("Blocks: %ld\n",databytes/waveformat.wBlockAlign);
   }
 
@@ -482,10 +495,9 @@ UseHours = 1, UseFrames =1:
 
 */
 long calcsplit (unsigned int UseHours, unsigned int UseFrames,
-                unsigned int fps,
-                int splitnr, timepos * split)
+                unsigned int fps, int splitnr, timepos * split)
 {
-  double TimeFloat;
+  double TimeFloat = 0.0;
   long pos;
   unsigned int Opt = 2 * UseHours + UseFrames;
 
@@ -519,16 +531,16 @@ long calcsplit (unsigned int UseHours, unsigned int UseFrames,
   pos = pos * waveformat.wBlockAlign;
 
   if (verbose)
-    printf ("[%02d]\tuntil %d:", splitnr + 1, split[splitnr].hr);
+    printf ("[%02d]\tuntil %5d ", splitnr + 1, split[splitnr].hr);
   if (UseFrames)
-    printf ("%d:%6.3f\t%09ld\t%3.2f%%\n",
+    printf ("%5d  %8.3f  %12ld    %3.2f%%\n",
             split[splitnr].min,
             (double) split[splitnr].seki +
             ((double) split[splitnr].frames / (double) fps), pos,
             (float) pos / (float) databytes * 100);
 
   else
-    printf ("%d:%6.3f\t%09ld\t%3.2f%%\n",
+    printf ("%5d  %8.3f  %12ld    %3.2f%%\n",
             split[splitnr].min,
             split[splitnr].sek, pos, (float) pos / (float) databytes * 100);
 
